@@ -305,12 +305,24 @@ def set_snapshot_data(node, items, snapshot_data):
     else:
         resource_items = items
 
+    includeSnapshotConfig = get_from_currentdata("INCLUDESNAPSHOTS")
+    includeSnapshots = get_from_currentdata("SNAPHSHOTIDS")
+    ignoreExclusion = False
+    ignoreNode = False
+    if includeSnapshotConfig:
+        if node['masterSnapshotId'] in includeSnapshots:
+            ignoreExclusion = True
+            ignoreNode = False
+        else:
+            ignoreNode  = True
+
     exclusions = get_from_currentdata(EXCLUSION).get('exclusions', [])
     resourceExclusions = {}
-    for exclusion in exclusions:
-        if 'exclusionType' in exclusion and exclusion['exclusionType'] and exclusion['exclusionType'] == 'resource':
-            if 'paths' in exclusion and isinstance(exclusion['paths'], list):
-                resourceExclusions[tuple(exclusion['paths'])] = exclusion
+    if not ignoreExclusion:
+        for exclusion in exclusions:
+            if 'exclusionType' in exclusion and exclusion['exclusionType'] and exclusion['exclusionType'] == 'resource':
+                if 'paths' in exclusion and isinstance(exclusion['paths'], list):
+                    resourceExclusions[tuple(exclusion['paths'])] = exclusion
 
     for item in resource_items:
         count += 1
@@ -340,17 +352,17 @@ def set_snapshot_data(node, items, snapshot_data):
             if key and key in resourceExclusions:
                 logger.warning("Excluded from resource exclusions: %s", path)
                 continue
-
-            snapshot_data[node['masterSnapshotId']].append(
-                {
-                    "masterSnapshotId" : [node['masterSnapshotId']],
-                    "snapshotId": '%s%s' % (node['masterSnapshotId'], str(count)),
-                    "type": resource_node_type,
-                    "collection": node['collection'],
-                    "path": path,
-                    "status" : "active",
-                    "validate" : node['validate'] if 'validate' in node else True
-                })
+            if not ignoreNode:
+                snapshot_data[node['masterSnapshotId']].append(
+                    {
+                        "masterSnapshotId" : [node['masterSnapshotId']],
+                        "snapshotId": '%s%s' % (node['masterSnapshotId'], str(count)),
+                        "type": resource_node_type,
+                        "collection": node['collection'],
+                        "path": path,
+                        "status" : "active",
+                        "validate" : node['validate'] if 'validate' in node else True
+                    })
     return snapshot_data
 
 def get_checksum(data):
