@@ -19,10 +19,11 @@ CFGFILE = 'config.ini'
 NONE = 'NONE'
 SNAPSHOT = 'SNAPSHOT'
 FULL = 'FULL'
+REMOTE = 'REMOTE'
 SINGLETEST = 'singletest'
 EXCLUSION = 'exclusion'
 CUSTOMER = "customer"
-DBVALUES = [NONE, SNAPSHOT, FULL]
+DBVALUES = [NONE, SNAPSHOT, FULL, REMOTE]
 CRAWL_AND_COMPLIANCE = "CRAWL_AND_COMPLIANCE"
 CRAWL = "CRAWL"
 COMPLIANCE = "COMPLIANCE"
